[llvm] r255818 - CXX_FAST_TLS calling convention: target independent portion.

Manman Ren via llvm-commits llvm-commits at lists.llvm.org
Wed Dec 16 12:45:48 PST 2015


Author: mren
Date: Wed Dec 16 14:45:48 2015
New Revision: 255818

URL: http://llvm.org/viewvc/llvm-project?rev=255818&view=rev
Log:
CXX_FAST_TLS calling convention: target independent portion.

Update supportSplitCSR's interface to take machine function instead of the
calling convention.

Review comments for http://reviews.llvm.org/D15341

Modified:
    llvm/trunk/include/llvm/Target/TargetLowering.h
    llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp

Modified: llvm/trunk/include/llvm/Target/TargetLowering.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Target/TargetLowering.h?rev=255818&r1=255817&r2=255818&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp (original)
+++ llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp Wed Dec 16 14:45:48 2015
@@ -470,9 +470,9 @@ bool SelectionDAGISel::runOnMachineFunct
   FuncInfo->SplitCSR = false;
   SmallVector<MachineBasicBlock*, 4> Returns;
 
-  // We split CSR if the target supports it for the given calling convention
+  // We split CSR if the target supports it for the given function
   // and the function has only return exits.
-  if (TLI->supportSplitCSR(Fn.getCallingConv())) {
+  if (TLI->supportSplitCSR(MF)) {
     FuncInfo->SplitCSR = true;
 
     // Collect all the return blocks.




More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/Target/TargetLowering.h (original)
+++ llvm/trunk/include/llvm/Target/TargetLowering.h Wed Dec 16 14:45:48 2015
@@ -2264,8 +2264,8 @@ public:
   }
 
   /// Return true if the target supports that a subset of CSRs for the given
-  /// calling convention is handled explicitly via copies.
-  virtual bool supportSplitCSR(CallingConv::ID CC) const {
+  /// machine function is handled explicitly via copies.
+  virtual bool supportSplitCSR(MachineFunction *MF) const {
     return false;
   }
 

Modified: llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp?rev=255818&r1=255817&r2=255818&view=diff
==============================================================================